==> blobAndConquer-0.8-2.tar.gz: blobAndConquer-0.8/src/entities/items.h <==
/*
Copyright (C) 2006 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "../headers.h"

extern void drawBoundingBox(BoundingBox *box);
extern void centerOnUnit(Unit *unit);
extern void triggerExplosion(float mapX, float mapY, float mapZ, int size);
extern void addThrowParticle(Entity *item);
extern void fireTriggers(char *name, int type);
extern bool withinViewableRange(Vector position, float size);
extern void drawBoundingBox(Entity *entity);
extern void addPowerUpParticles(Vector position);
extern Unit *findTeeka();
extern void drawCyclinder(Vector position, int segments, float size, float height, GLColor c);
extern void moveEntity(Entity *entity);
extern bool withinViewableRange(Entity *entity);
extern int getAdjustedHealthChance(int in, int minimum);
extern void drawBox(Vector position, float width, float length, float height);

extern Audio *audio;
extern BSP *bsp;
extern BoundingBoxManager *bbManager;
extern Camera *camera;
extern Engine *engine;
extern EntityManager *entityManager;
extern Game *game;
extern Graphics *graphics;
extern LocaleManager *localeManager;
extern Map *map;
extern Mission *mission;
extern TextureManager *textureManager;
extern Trace *tracer;
extern Unit *player;

==> blobAndConquer-0.91-1.tar.gz: blobAndConquer-0.91/src/entities/items.h <==
/*
Copyright (C) 2006 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "../headers.h"

extern void drawBoundingBox(BoundingBox *box);
extern void centerOnUnit(Unit *unit);
extern void triggerExplosion(float mapX, float mapY, float mapZ, int size);
extern void addThrowParticle(Entity *item);
extern void fireTriggers(char *name, int type);
extern bool withinViewableRange(Vector position, float size);
extern void drawBoundingBox(Entity *entity);
extern void addPowerUpParticles(Vector position);
extern Unit *findTeeka();
extern void drawCyclinder(Vector position, int segments, float size, float height, GLColor c);
extern void moveEntity(Entity *entity);
extern bool withinViewableRange(Entity *entity);
extern int getAdjustedHealthChance(int in, int minimum);
extern void drawBox(Vector position, float width, float length, float height, float tcm);

extern Audio *audio;
extern BSP *bsp;
extern BoundingBoxManager *bbManager;
extern Camera *camera;
extern Engine *engine;
extern EntityManager *entityManager;
extern Game *game;
extern Graphics *graphics;
extern Map *map;
extern Mission *mission;
extern TextureManager *textureManager;
extern Trace *tracer;
extern Unit *player;
